( cd usr/lib ; rm -rf libglade-2.0.so.0 )
( cd usr/lib ; ln -sf libglade-2.0.so.0.0.7 libglade-2.0.so.0 )
( cd usr/lib ; rm -rf libglade-2.0.so )
( cd usr/lib ; ln -sf libglade-2.0.so.0.0.7 libglade-2.0.so )
